@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -478,6 +478,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         recommender.*.list IAM permission for the specified insight
         type.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_list_insights():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.ListInsightsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_insights(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.ListInsightsRequest, dict]):
                 The request object. Request for the `ListInsights`
@@ -519,7 +540,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -573,6 +594,26 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested insight. Requires the recommender.*.get IAM
         permission for the specified insight type.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_get_insight():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.GetInsightRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_insight(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.GetInsightRequest, dict]):
                 The request object. Request to the `GetInsight` method.
@@ -596,7 +637,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -654,6 +695,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified insight.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_mark_insight_accepted():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.MarkInsightAcceptedRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_insight_accepted(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.MarkInsightAcceptedRequest, dict]):
                 The request object. Request for the
@@ -692,7 +754,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
@@ -746,6 +808,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         the recommender.*.list IAM permission for the specified
         recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_list_recommendations():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.ListRecommendationsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_recommendations(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.ListRecommendationsRequest, dict]):
                 The request object. Request for the
@@ -813,7 +896,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
@@ -869,6 +952,26 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested recommendation. Requires the
         recommender.*.get IAM permission for the specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_get_recommendation():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.GetRecommendationRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_recommendation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.GetRecommendationRequest, dict]):
                 The request object. Request to the `GetRecommendation`
@@ -893,7 +996,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -956,6 +1059,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_mark_recommendation_claimed():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.MarkRecommendationClaimedRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_recommendation_claimed(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.MarkRecommendationClaimedRequest, dict]):
                 The request object. Request for the
@@ -997,7 +1121,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
@@ -1068,6 +1192,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_mark_recommendation_succeeded():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.MarkRecommendationSucceededRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_recommendation_succeeded(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.MarkRecommendationSucceededRequest, dict]):
                 The request object. Request for the
@@ -1109,7 +1254,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
@@ -1180,6 +1325,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1
+
+            def sample_mark_recommendation_failed():
+                # Create a client
+                client = recommender_v1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1.MarkRecommendationFailedRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_recommendation_failed(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1.types.MarkRecommendationFailedRequest, dict]):
                 The request object. Request for the
@@ -1221,7 +1387,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
