@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,6 +29,7 @@ from .types.recommendation import Recommendation
 from .types.recommendation import RecommendationContent
 from .types.recommendation import RecommendationStateInfo
 from .types.recommendation import SecurityProjection
+from .types.recommendation import SustainabilityProjection
 from .types.recommendation import ValueMatcher
 from .types.recommender_config import RecommenderConfig
 from .types.recommender_config import RecommenderGenerationConfig
@@ -76,6 +77,7 @@ __all__ = (
     "RecommenderConfig",
     "RecommenderGenerationConfig",
     "SecurityProjection",
+    "SustainabilityProjection",
     "UpdateInsightTypeConfigRequest",
     "UpdateRecommenderConfigRequest",
     "ValueMatcher",
