@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -521,6 +521,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         recommender.*.list IAM permission for the specified insight
         type.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_list_insights():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.ListInsightsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_insights(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.ListInsightsRequest, dict]):
                 The request object. Request for the `ListInsights`
@@ -562,7 +583,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -616,6 +637,26 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested insight. Requires the recommender.*.get IAM
         permission for the specified insight type.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_get_insight():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.GetInsightRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_insight(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.GetInsightRequest, dict]):
                 The request object. Request to the `GetInsight` method.
@@ -639,7 +680,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -697,6 +738,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified insight.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_mark_insight_accepted():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.MarkInsightAcceptedRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_insight_accepted(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.MarkInsightAcceptedRequest, dict]):
                 The request object. Request for the
@@ -735,7 +797,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
@@ -789,6 +851,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         the recommender.*.list IAM permission for the specified
         recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_list_recommendations():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.ListRecommendationsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_recommendations(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.ListRecommendationsRequest, dict]):
                 The request object. Request for the
@@ -856,7 +939,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
@@ -912,6 +995,26 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested recommendation. Requires the
         recommender.*.get IAM permission for the specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_get_recommendation():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.GetRecommendationRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_recommendation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.GetRecommendationRequest, dict]):
                 The request object. Request to the `GetRecommendation`
@@ -936,7 +1039,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -999,6 +1102,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_mark_recommendation_claimed():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.MarkRecommendationClaimedRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_recommendation_claimed(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.MarkRecommendationClaimedRequest, dict]):
                 The request object. Request for the
@@ -1040,7 +1164,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
@@ -1111,6 +1235,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_mark_recommendation_succeeded():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.MarkRecommendationSucceededRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_recommendation_succeeded(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.MarkRecommendationSucceededRequest, dict]):
                 The request object. Request for the
@@ -1152,7 +1297,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
@@ -1223,6 +1368,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_mark_recommendation_failed():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.MarkRecommendationFailedRequest(
+                    name="name_value",
+                    etag="etag_value",
+                )
+
+                # Make the request
+                response = client.mark_recommendation_failed(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.MarkRecommendationFailedRequest, dict]):
                 The request object. Request for the
@@ -1264,7 +1430,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, state_metadata, etag])
         if request is not None and has_flattened_params:
@@ -1318,6 +1484,26 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested Recommender Config. There is only
         one instance of the config for each Recommender.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_get_recommender_config():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.GetRecommenderConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_recommender_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.GetRecommenderConfigRequest, dict]):
                 The request object. Request for the
@@ -1347,7 +1533,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 Configuration for a Recommender.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1396,6 +1582,25 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Updates a Recommender Config. This will create a new
         revision of the config.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_update_recommender_config():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.UpdateRecommenderConfigRequest(
+                )
+
+                # Make the request
+                response = client.update_recommender_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.UpdateRecommenderConfigRequest, dict]):
                 The request object. Request for the
@@ -1423,7 +1628,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 Configuration for a Recommender.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([recommender_config, update_mask])
         if request is not None and has_flattened_params:
@@ -1477,6 +1682,26 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested InsightTypeConfig. There is only
         one instance of the config for each InsightType.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_get_insight_type_config():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.GetInsightTypeConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_insight_type_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.GetInsightTypeConfigRequest, dict]):
                 The request object. Request for the
@@ -1506,7 +1731,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 Configuration for an InsightType.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1555,6 +1780,25 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Updates an InsightTypeConfig change. This will create
         a new revision of the config.
 
+
+        .. code-block:: python
+
+            from google.cloud import recommender_v1beta1
+
+            def sample_update_insight_type_config():
+                # Create a client
+                client = recommender_v1beta1.RecommenderClient()
+
+                # Initialize request argument(s)
+                request = recommender_v1beta1.UpdateInsightTypeConfigRequest(
+                )
+
+                # Make the request
+                response = client.update_insight_type_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.recommender_v1beta1.types.UpdateInsightTypeConfigRequest, dict]):
                 The request object. Request for the
@@ -1582,7 +1826,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 Configuration for an InsightType.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([insight_type_config, update_mask])
         if request is not None and has_flattened_params:
