@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,6 +31,7 @@ __protobuf__ = proto.module(
         "ValueMatcher",
         "CostProjection",
         "SecurityProjection",
+        "SustainabilityProjection",
         "Impact",
         "RecommendationStateInfo",
     },
@@ -351,6 +352,24 @@ class SecurityProjection(proto.Message):
     details = proto.Field(proto.MESSAGE, number=2, message=struct_pb2.Struct,)
 
 
+class SustainabilityProjection(proto.Message):
+    r"""Contains metadata about how much sustainability a
+    recommendation can save or incur.
+
+    Attributes:
+        kg_c_o2e (float):
+            Carbon Footprint generated in kg of CO2 equivalent. Chose
+            kg_c_o2e so that the name renders correctly in camelCase
+            (kgCO2e).
+        duration (google.protobuf.duration_pb2.Duration):
+            Duration for which this sustanability
+            applies.
+    """
+
+    kg_c_o2e = proto.Field(proto.DOUBLE, number=1,)
+    duration = proto.Field(proto.MESSAGE, number=2, message=duration_pb2.Duration,)
+
+
 class Impact(proto.Message):
     r"""Contains the impact a recommendation can have for a given
     category.
@@ -372,6 +391,10 @@ class Impact(proto.Message):
         security_projection (google.cloud.recommender_v1beta1.types.SecurityProjection):
             Use with CategoryType.SECURITY
 
+            This field is a member of `oneof`_ ``projection``.
+        sustainability_projection (google.cloud.recommender_v1beta1.types.SustainabilityProjection):
+            Use with CategoryType.SUSTAINABILITY
+
             This field is a member of `oneof`_ ``projection``.
     """
 
@@ -391,6 +414,12 @@ class Impact(proto.Message):
     security_projection = proto.Field(
         proto.MESSAGE, number=101, oneof="projection", message="SecurityProjection",
     )
+    sustainability_projection = proto.Field(
+        proto.MESSAGE,
+        number=102,
+        oneof="projection",
+        message="SustainabilityProjection",
+    )
 
 
 class RecommendationStateInfo(proto.Message):
